// Copyright (c) 1999-2003  ETH Zurich (Switzerland).
// All rights reserved.
//
// This file is part of CGAL (www.cgal.org); you may redistribute it under
// the terms of the Q Public License version 1.0.
// See the file LICENSE.QPL distributed with CGAL.
//
// Licensees holding a valid commercial license may use this file in
// accordance with the commercial license agreement provided with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Min_quadrilateral_2/include/CGAL/minimum_enclosing_quadrilateral_2.h $
// $Id: minimum_enclosing_quadrilateral_2.h 48717 2009-04-08 11:54:51Z spion $
// 
//
// Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch> and
//                 Emo Welzl <emo@inf.ethz.ch>

#ifndef CGAL_MINIMUM_ENCLOSING_QUADRILATERAL_2_H
#define CGAL_MINIMUM_ENCLOSING_QUADRILATERAL_2_H 1

#ifndef CGAL_NO_DEPRECATED_CODE
#include <CGAL/min_quadrilateral_2.h>
#endif // CGAL_NO_DEPRECATED_CODE

#endif // ! (CGAL_MINIMUM_ENCLOSING_QUADRILATERAL_2_H)

// ----------------------------------------------------------------------------
// ** EOF
// ----------------------------------------------------------------------------

